searchNodes=[{"ref":"Sandbox.html","title":"Sandbox","type":"module","doc":"Sandbox provides restricted, isolated scripting environments for Elixir through the use of embedded Lua. This project is powered by Robert Virding&#39;s amazing Luerl, an Erlang library that lets one execute Lua scripts on the BEAM. Luerl executes Lua code without running a Lua VM as a separate application! Rather, the state of the VM is used as a data structure that can be externally manipulated and processed. The :luerl_sandbox module is utilized wherever possible. This limits access to dangerous core libraries. It also permits Lua scripts to be run with enforced CPU reduction limits. To work with Lua&#39;s full library, use Sandbox.unsafe_init/0 as opposed to Sandbox.init/0. Conventions followed in this library: Functions beginning with eval return a Lua result. Functions starting with play return a new Lua VM state. Functions preceded by run return a tuple of {result, new_state} All functions return ok-error tuples such as {:ok, result} or {:error, reason} unless followed by a bang. Elixir functions exposed to Lua should all take two arguments: a Lua state and a list of Lua arguments. They should return a value corresponding to the eval, play or run responses."},{"ref":"Sandbox.html#chunk/2","title":"Sandbox.chunk/2","type":"function","doc":"Create a compiled chunk of Lua code that can be transferred between Lua states, returned in an ok-error tuple."},{"ref":"Sandbox.html#chunk!/2","title":"Sandbox.chunk!/2","type":"function","doc":"Same as chunk/2, but will return the raw result or raise a RuntimeError."},{"ref":"Sandbox.html#eval/3","title":"Sandbox.eval/3","type":"function","doc":"Evaluates a Lua string or chunk against the given Lua state and returns the result in an ok-error tuple. The state itself is not modified."},{"ref":"Sandbox.html#eval!/3","title":"Sandbox.eval!/3","type":"function","doc":"Same as eval/3, but will return the raw result or raise a RuntimeError."},{"ref":"Sandbox.html#eval_file/3","title":"Sandbox.eval_file/3","type":"function","doc":"Evaluates a Lua file against the given Lua state and returns the result in an ok-error tuple. The state itself is not modified."},{"ref":"Sandbox.html#eval_file!/3","title":"Sandbox.eval_file!/3","type":"function","doc":"Same as eval_file/3, but will return the raw result or raise a RuntimeError."},{"ref":"Sandbox.html#eval_function!/4","title":"Sandbox.eval_function!/4","type":"function","doc":"Calls a function defined in the the Lua state and returns only the result. The state itself is not modified. Lua functions in the Lua state can be referenced by their lua_path, being a string or list such as math.floor or [&quot;math&quot;, &quot;floor&quot;]."},{"ref":"Sandbox.html#get!/2","title":"Sandbox.get!/2","type":"function","doc":"Gets a value from a Lua state."},{"ref":"Sandbox.html#init/0","title":"Sandbox.init/0","type":"function","doc":"Creates a Lua state with sandbox features."},{"ref":"Sandbox.html#play/3","title":"Sandbox.play/3","type":"function","doc":"Runs a Lua string or chunk against a Lua state and returns a new Lua state in an ok-error tuple."},{"ref":"Sandbox.html#play!/3","title":"Sandbox.play!/3","type":"function","doc":"Same as play/3, but will return the raw result or raise a RuntimeError."},{"ref":"Sandbox.html#play_file!/3","title":"Sandbox.play_file!/3","type":"function","doc":"Runs a Lua file in the context of a Lua state and returns a new Lua state."},{"ref":"Sandbox.html#play_function!/4","title":"Sandbox.play_function!/4","type":"function","doc":"Runs a Lua function defined in the given Lua state and returns a new Lua state."},{"ref":"Sandbox.html#run/3","title":"Sandbox.run/3","type":"function","doc":"Runs a Lua string or chunk against the given Lua state and returns the result and the new Lua state in an ok-error tuple."},{"ref":"Sandbox.html#run!/3","title":"Sandbox.run!/3","type":"function","doc":"Same as run/3, but will return the raw {result, state} or raise a RuntimeError."},{"ref":"Sandbox.html#run_function!/4","title":"Sandbox.run_function!/4","type":"function","doc":"Runs a function defined in the the Lua state and returns the result and the new Lua state as {result, state}. Lua functions in the Lua state can be referenced by their lua_path, a string or list such as math.floor or [&quot;math&quot;, &quot;floor&quot;]."},{"ref":"Sandbox.html#set!/4","title":"Sandbox.set!/4","type":"function","doc":"Sets a value in a Lua state and returns the modified state. If force is set to true, new tables will be created automatically if they missing from the given lua_path."},{"ref":"Sandbox.html#set_elixir_to_eval!/3","title":"Sandbox.set_elixir_to_eval!/3","type":"function","doc":"Exposes an Elixir function for use within the Lua state. This function cannot modify the state of the Lua VM; it can only return a value."},{"ref":"Sandbox.html#set_elixir_to_play!/3","title":"Sandbox.set_elixir_to_play!/3","type":"function","doc":"Exposes an Elixir function that can modify the Lua state of the script calling it. This is primarily for letting Lua scripts use something like inheritance, dynamically adding external functionality and settings. The given Elixir function will receive two arguments, a Lua state and a list containing any arguments from Lua. It should return a new Lua VM state. This function will return a new Lua state with access to the Elixir function at the given table path."},{"ref":"Sandbox.html#set_elixir_to_run!/3","title":"Sandbox.set_elixir_to_run!/3","type":"function","doc":""},{"ref":"Sandbox.html#unsafe_init/0","title":"Sandbox.unsafe_init/0","type":"function","doc":""},{"ref":"Sandbox.html#t:elixir_eval_fun/0","title":"Sandbox.elixir_eval_fun/0","type":"type","doc":""},{"ref":"Sandbox.html#t:elixir_play_fun/0","title":"Sandbox.elixir_play_fun/0","type":"type","doc":""},{"ref":"Sandbox.html#t:elixir_run_fun/0","title":"Sandbox.elixir_run_fun/0","type":"type","doc":""},{"ref":"Sandbox.html#t:lua_chunk/0","title":"Sandbox.lua_chunk/0","type":"type","doc":""},{"ref":"Sandbox.html#t:lua_code/0","title":"Sandbox.lua_code/0","type":"type","doc":""},{"ref":"Sandbox.html#t:lua_path/0","title":"Sandbox.lua_path/0","type":"type","doc":""},{"ref":"Sandbox.html#t:lua_result/0","title":"Sandbox.lua_result/0","type":"type","doc":""},{"ref":"Sandbox.html#t:lua_state/0","title":"Sandbox.lua_state/0","type":"type","doc":""}]